package menu;

import javax.microedition.lcdui.*;
/**
* A Page is the basic element in a hierarchy of displayable
* pages.  This abstract class is extended to define
* specific types of behavior by specific types of pages.
*/
public abstract class Page {
	/**
	* Initialize a new Page object using the supplied parameters.
	* @param label short label for this page (as might be used in
	* a menu).  Must not be null.
	* @param title longer label for this page (as might be used in
	* a screen title).
	* @param icon small icon for this page (as might be used in
	* a toolbar or menu.
	*/
	public Page(String label,String title,Image icon) {
		if (label==null) throw new IllegalArgumentException("null Page label not allowed.");
		this.label = label;
		this.title = title;
		this.icon = icon;
	}
	/**
	* Return the Displayable object for this Page, completely filled in
	* and ready to display.
	* @return the appropriate Displayable object for this Page
	*/
	public abstract Displayable getDisplayable();
	/**
	* Process the user command and return an integer value telling
	* the PageMgr what to do next.  This method handles the details
	* of a command for a page, while the commandAction method in the
	* PageMgr handles the general responsibility of switching displays.
	* @param c a Command object identifying the command.
	* @param d the Displayable on which this event has occurred
	* @return a pageAction code, selected from the public fields defined
	* by PageMgr.
	*/
	public abstract int doCommandAction(Command c,Displayable d);
	/**
	* Return the Page that this Page feels should be the next page
	* to be displayed.  This method is called by the PageMgr after
	* doCommandAction returns PageMgr.LINK as the pageAction value.
	* If the subclass can return this pageAction, then it must 
	* override this implementation of getLinkedPage with an 
	* appropriate implementation that does not throw an Exception.
	* @throws IllegalStateException this implementation always 
	* throws this exception
	* @return Page the next Page to be displayed
	*/
	public Page getLinkedPage() {
		throw new IllegalStateException(
		"getLinkedPage() not implemented in "+
		this.getClass().getName());
	}
	/**
	* Return Page label.
	* @return Page label
	*/
	public String getLabel() {
		return label;
	}
	/**
	* Return Page title.
	* @return Page title
	*/
	public String getTitle() {
		return title;
	}
	/**
	* Return Page icon.
	* @return Page icon
	*/
	public Image getIcon() {
		return icon;
	}
	/**
	* Return pointer to previous page visited.
	* @return previous Page
	*/
	public Page getPrevious() {
		return previous;
	}
	/**
	* Set pointer to previous page visited.
	* @param p previous Page
	*/
	public void setPrevious(Page p) {
		previous = p;
	}
	//----------------------------------------------------------------------
	
	/** short label for this page (as might be used in a menu) */
	private String label;
	/** longer label for this page (as might be used in a screen title) */
	private String title;
	/** small icon for this page (as might be used in a toolbar or menu) */
	private Image icon;
	
	/** pointer to the previously visited Page */
	private Page previous;
}
